import SwiftUI

extension Grid {
    public func padding(_ length: CGFloat = 8) -> some View {
        self.environment(\.gridStyle.padding, EdgeInsets(top: length, leading: length, bottom: length, trailing: length))
    }
    
    public func padding(_ insets: EdgeInsets) -> some View {
        self.environment(\.gridStyle.padding, insets)
    }
    
    public func padding(_ edges: Edge.Set = .all, _ length: CGFloat? = nil) -> some View {
        var edgeInsets = EdgeInsets(top: 0, leading: 0, bottom: 0, trailing: 0)
        
        if let length = length {
            if edges.contains(.all) || edges.contains(.top) || edges.contains(.vertical) {
                edgeInsets.top = length
            }
            if edges.contains(.all) || edges.contains(.leading) || edges.contains(.horizontal) {
                edgeInsets.leading = length
            }
            if edges.contains(.all) || edges.contains(.bottom) || edges.contains(.vertical) {
                edgeInsets.bottom = length
            }
            if edges.contains(.all) || edges.contains(.trailing) || edges.contains(.horizontal) {
                edgeInsets.trailing = length
            }
        }
        return self.environment(\.gridStyle.padding, edgeInsets)
    }
}
